==> stix2_validator-0.0.1-py2.py3-none-any.whl: stix2validator/test/vulnerability_tests.py <==
import unittest
import copy
import json
from . import SCHEMA_DIR
from .. import validate_string
from ..validators import ValidationOptions

VALID_VULNERABILITY = """
{
  "type": "vulnerability",
  "id": "vulnerability--0c7b5b88-8ff7-4a4d-aa9d-feb398cd0061",
  "created": "2016-05-12T08:17:27.000000Z",
  "modified": "2016-05-12T08:17:27.000000Z",
  "version": 1,
  "name": "CVE-2016-1234",
  "external_references": [
    {
      "source_name": "cve",
      "external_id": "CVE-2016-1234"
    }
  ]
}
"""


class VulnerabilityTestCases(unittest.TestCase):
    valid_vulnerability = json.loads(VALID_VULNERABILITY)
    options = ValidationOptions(schema_dir=SCHEMA_DIR)

    def test_wellformed_vulnerability(self):
        results = validate_string(VALID_VULNERABILITY, self.options)
        self.assertTrue(results.is_valid)

    def test_incorrect_cve_format(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "2016-1234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_number(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "CVE-20161234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_letter(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "CVE-2016-abc"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_lowercase(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "cve-2016-1234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_source_name(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['source_name'] = "CVE"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)


if __name__ == "__main__":
    unittest.main()

==> stix2_validator-0.2.0-py2.py3-none-any.whl: stix2validator/test/vulnerability_tests.py <==
import unittest
import copy
import json
from . import SCHEMA_DIR
from .. import validate_string
from ..util import ValidationOptions

VALID_VULNERABILITY = """
{
  "type": "vulnerability",
  "id": "vulnerability--0c7b5b88-8ff7-4a4d-aa9d-feb398cd0061",
  "created": "2016-05-12T08:17:27.000000Z",
  "modified": "2016-05-12T08:17:27.000000Z",
  "name": "CVE-2016-1234",
  "external_references": [
    {
      "source_name": "cve",
      "external_id": "CVE-2016-1234"
    }
  ]
}
"""


class VulnerabilityTestCases(unittest.TestCase):
    valid_vulnerability = json.loads(VALID_VULNERABILITY)
    options = ValidationOptions(schema_dir=SCHEMA_DIR)

    def test_wellformed_vulnerability(self):
        results = validate_string(VALID_VULNERABILITY, self.options)
        self.assertTrue(results.is_valid)

    def test_incorrect_cve_format(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "2016-1234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_number(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "CVE-20161234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_letter(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "CVE-2016-abc"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_format_lowercase(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['external_id'] = "cve-2016-1234"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)

    def test_incorrect_cve_source_name(self):
        vulnerability = copy.deepcopy(self.valid_vulnerability)
        ext_refs = vulnerability['external_references']
        ext_refs[0]['source_name'] = "CVE"
        vulnerability = json.dumps(vulnerability)
        results = validate_string(vulnerability, self.options)
        self.assertEqual(results.is_valid, False)


if __name__ == "__main__":
    unittest.main()
